@@ -102,7 +102,7 @@ test_that("as.data.frame for dfm objects", {
     d <- data_dfm_lbgexample[, 1:5]
     expect_equal(
         suppressWarnings(as.data.frame(d)),
-        data.frame(document = docnames(d), as.matrix(d), stringsAsFactors = FALSE, row.names = NULL)
+        data.frame(doc_id = docnames(d), as.matrix(d), stringsAsFactors = FALSE, row.names = NULL)
     )
     expect_equal(
         suppressWarnings(as.data.frame(d, document = NULL)),
@@ -110,7 +110,7 @@ test_that("as.data.frame for dfm objects", {
     )
     expect_equal(
         suppressWarnings(as.data.frame(d, row.names = docnames(d))),
-        data.frame(document = docnames(d), as.matrix(d), stringsAsFactors = FALSE, row.names = docnames(d))
+        data.frame(doc_id = docnames(d), as.matrix(d), stringsAsFactors = FALSE, row.names = docnames(d))
     )
     expect_error(
         suppressWarnings(as.data.frame(d, document = TRUE)),
@@ -124,13 +124,20 @@ test_that("dfm2dataframe same as as.data.frame.dfm", {
         suppressWarnings(as.data.frame(d)),
         convert(d, to = "data.frame")
     )
+    expect_identical(
+        suppressWarnings(as.data.frame(d, document = NULL, 
+                                       row.names = docnames(d))),
+        data.frame(as.matrix(d), stringsAsFactors = FALSE, 
+                   row.names = docnames(d))
+    )
     expect_equal(
         quanteda:::dfm2dataframe(d, document = NULL),
         data.frame(as.matrix(d), stringsAsFactors = FALSE, row.names = NULL)
     )
     expect_equal(
         quanteda:::dfm2dataframe(d, row.names = docnames(d)),
-        data.frame(document = docnames(d), as.matrix(d), stringsAsFactors = FALSE, row.names = docnames(d))
+        data.frame(doc_id = docnames(d), as.matrix(d), stringsAsFactors = FALSE, 
+                   row.names = docnames(d))
     )
     expect_error(
         quanteda:::dfm2dataframe(d, document = TRUE),
@@ -145,19 +152,21 @@ test_that("as.data.frame.dfm handles irregular feature names correctly", {
                  dictionary = dictionary(list("字" = "a", "spe cial" = "the", 
                                               "飛機" = "if", "spec+ial" = "of")))
     expect_equal(
-        names(convert(mydfm, to = "data.frame")),
+        names(convert(mydfm, to = "data.frame", docid_field = "document")),
         c("document", "字", "spe cial", "飛機", "spec+ial")
     )
     expect_equal(
-        suppressWarnings(names(as.data.frame(mydfm, check.names = TRUE))),
+        suppressWarnings(names(as.data.frame(mydfm, check.names = TRUE, 
+                                             docid_field = "document"))),
         c("document", "字", "spe.cial", "飛機", "spec.ial")
     )
     expect_equal(
-        names(quanteda:::dfm2dataframe(mydfm)),
+        names(quanteda:::dfm2dataframe(mydfm, docid_field = "document")),
         c("document", "字", "spe cial", "飛機", "spec+ial")
     )
     expect_equal(
-        names(quanteda:::dfm2dataframe(mydfm, check.names = TRUE)),
+        names(quanteda:::dfm2dataframe(mydfm, check.names = TRUE, 
+                                       docid_field = "document")),
         c("document", "字", "spe.cial", "飛機", "spec.ial")
     )
 })
