@@ -4,11 +4,11 @@ test_that("test textstat_entropy is working", {
     skip_if_not_installed("entropy")
     
     mt <- data_dfm_lbgexample
-    expect_identical(unname(apply(mt, 1, entropy::entropy, unit = "log2")),
-                     textstat_entropy(mt, "documents")[["entropy"]])
+    expect_equal(unname(apply(mt, 1, entropy::entropy, unit = "log2")),
+                 textstat_entropy(mt, "documents")[["entropy"]])
     expect_equal(unname(apply(mt, 2, entropy::entropy, unit = "log2")),
                  textstat_entropy(mt, "features")[["entropy"]])
-    expect_identical(unname(apply(mt, 1, entropy::entropy, unit = "log10")),
+    expect_equal(unname(apply(mt, 1, entropy::entropy, unit = "log10")),
                  textstat_entropy(mt, "documents", base = 10)[["entropy"]])
     expect_equal(unname(apply(mt, 2, entropy::entropy, unit = "log10")),
                  textstat_entropy(mt, "features", base = 10)[["entropy"]])
