@@ -1,28 +1,28 @@
 context("test textstat_keyness()")
 
 test_that("keyness_textstat chi2 computation is correct", {
-    mydfm <- dfm(c(d1 = "b b b b b b b a a a",
+    dfmt <- dfm(c(d1 = "b b b b b b b a a a",
                    d2 = "a a a a a a a b b"))
     suppressWarnings(
-        result <- stats::chisq.test(as.matrix(mydfm), correct = TRUE)
+        result <- stats::chisq.test(as.matrix(dfmt), correct = TRUE)
     )
     expect_equivalent(
         result$statistic,
-        textstat_keyness(mydfm, sort = FALSE, correction = "default")[[1, 2]]
-    )
-    expect_equal(
-        as.numeric(textstat_keyness(mydfm, sort = FALSE, measure = "chi2", correction = "williams")[1, "chi2"]),
-        4.017626,
-        tolerance = .00001
+        textstat_keyness(dfmt, sort = FALSE, correction = "default")[[1, 2]]
     )
+    # expect_equal(
+    #     as.numeric(textstat_keyness(dfmt, sort = FALSE, measure = "chi2", correction = "williams")[1, "chi2"]),
+    #     4.017626,
+    #     tolerance = .00001
+    # )
     
     # without Yates correction
     suppressWarnings(
-        result <- stats::chisq.test(as.matrix(mydfm), correct = FALSE)
+        result <- stats::chisq.test(as.matrix(dfmt), correct = FALSE)
     )
     expect_equivalent(
         result$statistic,
-        textstat_keyness(mydfm, sort = FALSE, correction = "none")[[1, 2]]
+        textstat_keyness(dfmt, sort = FALSE, correction = "none")[[1, 2]]
     )
 })
 
@@ -30,37 +30,37 @@ test_that("keyness_textstat chi2 computation is correct for three rows", {
     txt <- c(d1 = "b b b b b b b a a a",
              d2 = "a a a a a a a b b",
              d3 = "a a a b b b")
-    mydfm <- dfm(txt)
-    mydfm_grouped <- dfm(txt, groups = c("target", "zref", "zref"))
+    dfmt <- dfm(txt)
+    dfmt_grouped <- dfm(txt, groups = c("target", "zref", "zref"))
     suppressWarnings(
-        result <- stats::chisq.test(as.matrix(mydfm_grouped), correct = TRUE)
+        result <- stats::chisq.test(as.matrix(dfmt_grouped), correct = TRUE)
     )
     expect_equal(
         as.numeric(result$statistic),
-        as.numeric(textstat_keyness(mydfm, sort = FALSE, correction = "default")[1, "chi2"])
+        as.numeric(textstat_keyness(dfmt, sort = FALSE, correction = "default")[1, "chi2"])
     )
     expect_equal(
-        as.numeric(textstat_keyness(mydfm, sort = FALSE, correction = "default")[1, "chi2"]),
-        as.numeric(textstat_keyness(mydfm, sort = FALSE, correction = "yates")[1, "chi2"])
+        as.numeric(textstat_keyness(dfmt, sort = FALSE, correction = "default")[1, "chi2"]),
+        as.numeric(textstat_keyness(dfmt, sort = FALSE, correction = "yates")[1, "chi2"])
     )
 
     # uncorrected
     suppressWarnings(
-        result <- stats::chisq.test(as.matrix(mydfm_grouped), correct = FALSE)
+        result <- stats::chisq.test(as.matrix(dfmt_grouped), correct = FALSE)
     )
     expect_equal(
         as.numeric(result$statistic),
-        as.numeric(textstat_keyness(mydfm, sort = FALSE, correction = "none")[1, "chi2"])
+        as.numeric(textstat_keyness(dfmt, sort = FALSE, correction = "none")[1, "chi2"])
     )
 })
 
 test_that("keyness_chi2 internal methods are equivalent", {
     skip("Skipped because stats::chisq.test is wrong for small-value 2x2 tables")
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
     expect_equal(
-        quanteda:::keyness_chi2_stats(mydfm),
-        quanteda:::keyness_chi2_dt(mydfm)
+        quanteda:::keyness_chi2_stats(dfmt),
+        quanteda:::keyness_chi2_dt(dfmt)
     )
 
     ## stats::chisq.test is wrong for small tables
@@ -80,14 +80,14 @@ test_that("keyness_chi2 internal methods are equivalent", {
 })
 
 test_that("basic textstat_keyness works on two rows", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
-    key1 <- textstat_keyness(mydfm)
+    key1 <- textstat_keyness(dfmt)
     expect_equal(key1$feature,
                  c("g", "c", "b", "h", "a", "e", "f", "d"))
     expect_equal(attr(key1, "groups"),
                  c("d1", "d2"))
-    key2 <- textstat_keyness(mydfm, target = 2)
+    key2 <- textstat_keyness(dfmt, target = 2)
     expect_equal(key2$feature,
                  c("d", "e", "f", "a", "b", "h", "c", "g"))
     expect_equal(attr(key2, "groups"),
@@ -96,59 +96,59 @@ test_that("basic textstat_keyness works on two rows", {
 })
 
 test_that("textstat_keyness works with different targets", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
-    expect_equal(textstat_keyness(mydfm),
-                 textstat_keyness(mydfm, target = 1))
-    expect_equal(textstat_keyness(mydfm, target = "d1"),
-                 textstat_keyness(mydfm, target = 1))
-    expect_equal(textstat_keyness(mydfm, target = "d2"),
-                 textstat_keyness(mydfm, target = 2))
-    expect_equal(textstat_keyness(mydfm, target = "d2"),
-                 textstat_keyness(mydfm, target = c(FALSE, TRUE)))
+    expect_equal(textstat_keyness(dfmt),
+                 textstat_keyness(dfmt, target = 1))
+    expect_equal(textstat_keyness(dfmt, target = "d1"),
+                 textstat_keyness(dfmt, target = 1))
+    expect_equal(textstat_keyness(dfmt, target = "d2"),
+                 textstat_keyness(dfmt, target = 2))
+    expect_equal(textstat_keyness(dfmt, target = "d2"),
+                 textstat_keyness(dfmt, target = c(FALSE, TRUE)))
 })
 
 test_that("textstat_keyness combines non-target rows correctly", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h",
                    d3 = "a a a a b b c c d d d d d d"))
     expect_equivalent(
-      textstat_keyness(mydfm, 1),
-      textstat_keyness(rbind(mydfm[1, ], mydfm[2, ], mydfm[3, ]), target = "d1")
+      textstat_keyness(dfmt, 1),
+      textstat_keyness(rbind(dfmt[1, ], dfmt[2, ], dfmt[3, ]), target = "d1")
     )
 })
 
 test_that("textstat_keyness errors", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
-    expect_error(textstat_keyness(mydfm, target = 3),
+    expect_error(textstat_keyness(dfmt, target = 3),
                  "target index outside range of documents")
-    expect_error(textstat_keyness(mydfm, target = "d3"),
+    expect_error(textstat_keyness(dfmt, target = "d3"),
                  "target not found in docnames\\(x\\)")
-    expect_error(textstat_keyness(mydfm[1, ]),
+    expect_error(textstat_keyness(dfmt[1, ]),
                  "x must have at least two documents")
 })
 
 test_that("keyness_textstat exact computation is correct", {
-    mydfm <- dfm(c(d1 = "b b b b b b b a a a",
+    dfmt <- dfm(c(d1 = "b b b b b b b a a a",
                    d2 = "a a a a a a a b b"))
-    result <- stats::fisher.test(as.matrix(mydfm))
+    result <- stats::fisher.test(as.matrix(dfmt))
     expect_equivalent(
         result$estimate,
-        textstat_keyness(mydfm, measure = "exact", sort = FALSE)[[1, 2]]
+        textstat_keyness(dfmt, measure = "exact", sort = FALSE)[[1, 2]]
     )
     expect_equivalent(
         result$p.value,
-        textstat_keyness(mydfm, measure = "exact", sort = FALSE)[[1, 3]]
+        textstat_keyness(dfmt, measure = "exact", sort = FALSE)[[1, 3]]
     )
 })
 
 test_that("basic textstat_keyness exact works on two rows", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
-    expect_equal(textstat_keyness(mydfm, measure = "exact")$feature,
+    expect_equal(textstat_keyness(dfmt, measure = "exact")$feature,
                  c("g", "c", "b", "h", "a", "e", "f", "d"))
-    expect_equal(textstat_keyness(mydfm, target = 2, measure = "exact")$feature,
+    expect_equal(textstat_keyness(dfmt, target = 2, measure = "exact")$feature,
                  c("d", "e", "f", "a", "b", "h", "c", "g"))
 })
 
@@ -223,70 +223,70 @@ likelihood.test <- function(x, y = NULL, conservative=FALSE) {
 }
 
 test_that("keyness_textstat lr computation is correct", {
-    mydfm <- dfm(c(d1 = "b b b b b b b a a a",
+    dfmt <- dfm(c(d1 = "b b b b b b b a a a",
                    d2 = "a a a a a a a b b"))
-    result <- likelihood.test(as.matrix(mydfm))
+    result <- likelihood.test(as.matrix(dfmt))
     expect_equivalent(
         result$statistic,
-        textstat_keyness(mydfm, measure = "lr", sort = FALSE, correction = "none")[[1, 2]]
+        textstat_keyness(dfmt, measure = "lr", sort = FALSE, correction = "none")[[1, 2]]
     )
     expect_equal(
         as.vector(result$p.value),
-        textstat_keyness(mydfm, measure = "lr", sort = FALSE, correction = "none")[[1, 3]]
+        textstat_keyness(dfmt, measure = "lr", sort = FALSE, correction = "none")[[1, 3]]
     )
 
     # with william's correction
-    result <- likelihood.test(as.matrix(mydfm), conservative = TRUE)
+    result <- likelihood.test(as.matrix(dfmt), conservative = TRUE)
     expect_equivalent(
         result$statistic,
-        textstat_keyness(mydfm, measure = "lr", sort = FALSE, correction = "williams")[[1, 2]]
+        textstat_keyness(dfmt, measure = "lr", sort = FALSE, correction = "williams")[[1, 2]]
     )
     expect_equal(
         as.vector(result$p.value),
-        textstat_keyness(mydfm, measure = "lr", sort = FALSE, correction = "williams")[[1, 3]]
+        textstat_keyness(dfmt, measure = "lr", sort = FALSE, correction = "williams")[[1, 3]]
     )
 })
 
 test_that("basic textstat_keyness lr works on two rows", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
-    expect_equal(textstat_keyness(mydfm, measure = "lr", correction = "none")$feature,
+    expect_equal(textstat_keyness(dfmt, measure = "lr", correction = "none")$feature,
                  c("c", "g", "b", "h", "a", "e", "f", "d"))
-    expect_equal(textstat_keyness(mydfm, target = 2, measure = "lr", correction = "none")$feature,
+    expect_equal(textstat_keyness(dfmt, target = 2, measure = "lr", correction = "none")$feature,
                  c("d", "e", "f", "a", "b", "h", "g", "c"))
-    expect_equal(textstat_keyness(mydfm, measure = "lr", sort = FALSE)$feature,
+    expect_equal(textstat_keyness(dfmt, measure = "lr", sort = FALSE)$feature,
                  letters[1:8])
 })
 
 test_that("textstat_keyness returns raw frequency counts", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
 
-    expect_equivalent(textstat_keyness(mydfm, measure = "chi2", sort = FALSE)[, c(4, 5)],
-                      suppressWarnings(as.data.frame(t(mydfm), document = NULL)))
+    expect_equivalent(textstat_keyness(dfmt, measure = "chi2", sort = FALSE)[, c(4, 5)],
+                      suppressWarnings(as.data.frame(t(dfmt), document = NULL)))
 
-    expect_equivalent(textstat_keyness(mydfm, measure = "exact", sort = FALSE)[, c(4, 5)],
-                      suppressWarnings(as.data.frame(t(mydfm), document = NULL)))
+    expect_equivalent(textstat_keyness(dfmt, measure = "exact", sort = FALSE)[, c(4, 5)],
+                      suppressWarnings(as.data.frame(t(dfmt), document = NULL)))
 
-    expect_equivalent(textstat_keyness(mydfm, measure = "lr", sort = FALSE)[, c(4, 5)],
-                      suppressWarnings(as.data.frame(t(mydfm), document = NULL)))
+    expect_equivalent(textstat_keyness(dfmt, measure = "lr", sort = FALSE)[, c(4, 5)],
+                      suppressWarnings(as.data.frame(t(dfmt), document = NULL)))
 
 })
 
 test_that("textstat_keyness returns correct pmi", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
     ## manual checking
-    mykeyness <- textstat_keyness(mydfm, measure = "pmi")
-    my_cal <- log(mydfm[1, 1] * sum(mydfm) / ((mydfm[1, 1] + mydfm[2, 1]) * sum(mydfm[1, ])))
-    expect_equal(colnames(mydfm)[1], "a")
+    mykeyness <- textstat_keyness(dfmt, measure = "pmi")
+    my_cal <- log(dfmt[1, 1] * sum(dfmt) / ((dfmt[1, 1] + dfmt[2, 1]) * sum(dfmt[1, ])))
+    expect_equal(colnames(dfmt)[1], "a")
     expect_equal(mykeyness$pmi[which(mykeyness$feature == "a")],
                  as.numeric(my_cal),
                  tolerance = 0.0001)
 
     skip_if_not_installed("svs")
-    svs_pmi <- svs::pmi(as.table(as.matrix(mydfm)), base = 2.7182818459)
-    mykeyness <- textstat_keyness(mydfm, measure = "pmi")
+    svs_pmi <- svs::pmi(as.table(as.matrix(dfmt)), base = 2.7182818459)
+    mykeyness <- textstat_keyness(dfmt, measure = "pmi")
 
     expect_equal(mykeyness$pmi[which(mykeyness$feature == "g")],
                  svs_pmi[1, which(attr(svs_pmi, "dimnames")$features == "g")],
@@ -296,21 +296,21 @@ test_that("textstat_keyness returns correct pmi", {
 })
 
 test_that("textstat_keyness correction warnings for pmi and exact", {
-    mydfm <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
+    dfmt <- dfm(c(d1 = "a a a b b c c c c c c d e f g h h",
                    d2 = "a a b c c d d d d e f h"))
     expect_warning(
-        textstat_keyness(mydfm, measure = "pmi", correction = "yates"),
-        "correction is always none for measure pmi"
+        textstat_keyness(dfmt, measure = "pmi", correction = "yates"),
+        "correction is always none for pmi"
     )
     expect_warning(
-        textstat_keyness(mydfm, measure = "exact", correction = "williams"),
-        "correction is always none for measure exact"
+        textstat_keyness(dfmt, measure = "exact", correction = "williams"),
+        "correction is always none for exact"
     )
     expect_silent(
-        textstat_keyness(mydfm, measure = "exact", correction = "none")
+        textstat_keyness(dfmt, measure = "exact", correction = "none")
     )
     expect_silent(
-        textstat_keyness(mydfm, measure = "pmi", correction = "none")
+        textstat_keyness(dfmt, measure = "pmi", correction = "none")
     )
 })
 
